@@ -1,6 +1,6 @@
 /***
 |''Name''|TiddlySpaceTiddlerIconsPlugin|
-|''Version''|0.6|
+|''Version''|0.6.1|
 |''Status''|@@beta@@|
 |''Author''|Jon Robson|
 |''Description''|Provides ability to render SiteIcons and icons that correspond to the home location of given tiddlers|
@@ -110,6 +110,27 @@ var originMacro = config.macros.tiddlerOrigin = {
 		"privateConfirmDelete": "Are you sure you want to delete all the private revisions of this tiddler?",
 		pleaseWait: "please wait.."
 	},
+	handler: function(place, macroName, params,wikifier, paramString, tiddler){
+		var adaptor = tiddler.getAdaptor();
+		var locale = originMacro.locale;
+		var type = "private";
+		if(tiddler && tiddler.fields["server.workspace"]) {
+			name = tiddler.fields["server.workspace"].replace("recipes/", "").
+			replace("bags/", "");
+		} else {
+			name = tiddler;
+		}
+		var options = originMacro.getOptions(params, paramString);
+		options.space = tiddlyspace.determineSpace(name, true);
+		var concertinaContentEl = $("<div />")[0];
+
+		var concertinaButton = originMacro.createConcertinaButton(place, concertinaContentEl);
+		type = originMacro.determineTiddlerType(tiddler, options, function(type) {
+			originMacro.renderIcon(tiddler, type, concertinaButton,
+				concertinaContentEl, options);
+		});
+	},
+
 	createConcertinaButton: function(place, concertinaContent) {
 		var concertinaButton = $('<a class="originButton" href="javascript:;" />').
 			click(function(ev) {
@@ -196,30 +217,17 @@ var originMacro = config.macros.tiddlerOrigin = {
 			}
 		}
 	},
-	handler: function(place, macroName, params,wikifier, paramString, tiddler){
-		var adaptor = tiddler.getAdaptor();
-		var locale = originMacro.locale;
-		var type = "private";
-		var parsedParams = paramString.parseParams("name")[0];
-		var includeLabel = parsedParams.label && parsedParams.label[0] == "yes";
+	getOptions: function(params, paramString) {
 		var options = {
-			labelOptions: { includeLabel: includeLabel },
+			labelOptions: originMacro._getLabelOptions(paramString.parseParams("name")),
 			imageOptions: imageMacro.getArguments(paramString, [])
 		};
-		if(tiddler && tiddler.fields["server.workspace"]) {
-			name = tiddler.fields["server.workspace"].replace("recipes/", "").
-			replace("bags/", "");
-		} else {
-			name = tiddler;
-		}
-		options.space = tiddlyspace.determineSpace(name, true);
-		var concertinaContentEl = $("<div />")[0];
-
-		var concertinaButton = originMacro.createConcertinaButton(place, concertinaContentEl);
-		type = originMacro.determineTiddlerType(tiddler, options, function(type) {
-			originMacro.renderIcon(tiddler, type, concertinaButton,
-				concertinaContentEl, options);
-		});
+		return options;
+	},
+	_getLabelOptions: function(parsedParams) {
+		var parsedParams = parsedParams[0];
+		var includeLabel = !parsedParams.label || ( parsedParams.label && parsedParams.label[0] == "yes" );
+		return { includeLabel: includeLabel };
 	},
 	renderIcon: function(tiddler, type, concertinaButton, concertinaContentEl, options) {
 		var locale = originMacro.locale;
